@@ -11,7 +11,7 @@ func PrivateKey() *config.Rule {
 	r := config.Rule{
 		Description: "Private Key",
 		RuleID:      "private-key",
-		Regex:       regexp.MustCompile(`(?i)-----\s*?BEGIN[ A-Z0-9_-]*?PRIVATE KEY\s*?-----[\s\S]*?----\s*?END[ A-Z0-9_-]*? PRIVATE KEY\s*?-----`),
+		Regex:       regexp.MustCompile(`(?i)-----BEGIN[ A-Z0-9_-]{0,100}PRIVATE KEY-----[\s\S-]*KEY----`),
 		Keywords:    []string{"-----BEGIN PRIVATE"},
 	}
 
@@ -19,5 +19,5 @@ func PrivateKey() *config.Rule {
 	tps := []string{`-----BEGIN PRIVATE KEY-----
 anything
 -----END PRIVATE KEY-----`} // gitleaks:allow
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
